<?php
/**
 * Developer : MahdiY
 * Web Site  : MahdiY.IR
 * E-Mail    : M@hdiY.IR
 */

defined( 'ABSPATH' ) || exit;

class PWS_SMS {

    public function __construct() {
        if (!PWS()::get_option('sms_config.enable')) {
            return false;
        }

        add_action('woocommerce_order_status_changed', [$this, 'order_status_changed'], 100, 3);
        add_action('pws_save_order_post_barcode', [$this, 'save_order_post_barcode'], 100, 2);
    }

    public function order_status_changed($order_id, $old_status = '', $new_status = 'created') {
        if (current_action() == 'woocommerce_process_shop_order_meta') {
            if (!is_admin()) {
                return false;
            }
        }

        if (!$order_id) {
            return false;
        }

        $data = PWS()::get_option('sms_order.wc-' . $new_status);

        if (empty($data)) {
            return false;
        }

        $order = new WC_Order($order_id);
        $phone = $order->get_billing_phone();

        $sms = self::send($order, $data);

        if ($sms === true) {
            $note = sprintf('پیامک "%s" با موفقیت به مشتری با شماره %s ارسال گردید.', wc_get_order_status_name($new_status), $phone);
        } else {
            $note = sprintf('پیامک "%s" بخاطر خطا به مشتری با شماره %s ارسال نشد.<br>پاسخ وبسرویس: %s', wc_get_order_status_name($new_status), $phone, $sms);
        }

        $order->add_order_note($note);
    }

    public function save_order_post_barcode(WC_Order $order, $barcode) {
        $data = PWS()::get_option('sms_event.barcode');

        if (empty($data)) {
            return false;
        }

        $phone = $order->get_billing_phone();

        $sms = self::send($order, $data);

        if ($sms === true) {
            $note = sprintf('پیامک "بارکد پستی" با موفقیت به مشتری با شماره %s ارسال گردید.', $phone);
        } else {
            $note = sprintf('پیامک "بارکد پستی" بخاطر خطا به مشتری با شماره %s ارسال نشد.<br>پاسخ وبسرویس: %s', $phone, $sms);
        }

        $order->add_order_note($note);
    }

    public static function send(WC_Order $order, $message) {
        $logger = wc_get_logger();
        $context = ['source' => 'pws_sms'];
    
        $phone = $order->get_billing_phone();
        $data = $message;
    
        $param = [
            "username"    => PWS()::get_option('sms_config.username'),
            "password"    => PWS()::get_option('sms_config.password'),
            "source"      => PWS()::get_option('sms_config.source'),
            "message"     => self::tags($order, $data),
            "destination" => self::sanitize_phone($phone)
        ];
    
        $url = "https://panel.asanak.com/webservice/v2rest/sendsms";
        $body = http_build_query($param);
    
        $args = [
            'method'    => 'POST',
            'body'      => $body,
            'headers'   => [
                'Content-Type' => 'application/x-www-form-urlencoded'
            ],
            'timeout'   => 30,
        ];
    
        $logger->info("🚀 ارسال پیامک به {$phone} با داده‌های: " . json_encode($param, JSON_UNESCAPED_UNICODE), $context);
    
        $sendResult = wp_remote_post($url, $args);
    
        // بررسی اینکه آیا درخواست با خطا مواجه شده است
        if (is_wp_error($sendResult)) {
            $error_message = $sendResult->get_error_message();
            $logger->error("❌ خطا در ارسال درخواست: {$error_message}", $context);
            return 'خطا در برقراری ارتباط';
        }
    
        $response_code = wp_remote_retrieve_response_code($sendResult);
        $response_body = wp_remote_retrieve_body($sendResult);
    
        // بررسی وضعیت پاسخ HTTP
        if ($response_code == 403) {
            $logger->error("🚫 خطای 403: دسترسی به وب‌سرویس مسدود شده است. لطفاً اعتبار API را بررسی کنید.", $context);
            return 'دسترسی به وب‌سرویس مسدود شده است (403)';
        }
    
        if (empty($response_body)) {
            $logger->error("⚠️ پاسخ وب‌سرویس خالی است. ممکن است درخواست توسط سرور مسدود شده باشد.", $context);
            return 'پاسخ دریافت نشده است';
        }
    
        $sms = json_decode($response_body, true);
        $logger->info("📩 پاسخ وب‌سرویس: " . json_encode($sms, JSON_UNESCAPED_UNICODE), $context);
    
        // بررسی پاسخ وب‌سرویس
        if (isset($sms['meta']['status']) && $sms['meta']['status'] == 200) {
            return true;
        } elseif (isset($sms['meta']['message'])) {
            return "❗ ارسال پیامک با خطا مواجه شد: " . $sms['meta']['message'];
        } else {
            return '❌ خطای نامشخص: ' . $response_body;
        }
    }
    

    public static function sanitize_phone($phone) {
        return str_replace(
            [
                '+98', '۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹',
                '٠', '١', '٢', '٣', '٤', '٥', '٦', '٧', '٨', '٩'
            ],
            [
                0, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9,
                0, 1, 2, 3, 4, 5, 6, 7, 8, 9
            ],
            $phone
        );
    }

    public static function tags(WC_Order $order, $data) {
        $tags = [
            '{order}' => $order->get_id(),
            '{first_name}' => $order->get_billing_first_name(),
            '{last_name}' => $order->get_billing_last_name(),
            '{barcode}' => $order->get_meta('post_barcode'),
            '{total}' => $order->get_total(),
        ];

        $tags = apply_filters('pws_sms_tags', $tags, $order, $data);
        $message = str_replace(array_keys($tags), array_values($tags), $data);

        return $message;
    }
}

new PWS_SMS();
